import os

import git


def download_repo_git(url, path):
    print('Download start...')
    if not os.path.exists(path):  # 不存在该路径，创建该路径
        os.mkdir(path)
        # 下载git仓库
        git.Repo.clone_from(url, path)
    else:
        # 存在该路径则清空该路径下的所有文件
        for file in os.listdir(path):
            if not file:  # 无旧数据
                # 下载git仓库
                git.Repo.clone_from(url, path)
            else:
                # 如果有旧数据，则拉取git仓库最新更新
                git.Repo(path).remotes.origin.pull()

    print('Successfully download')
    print(os.listdir(path))


def download_repo(url, path='./download_repo/', url_type='git'):
    if url_type == 'git':
        download_repo_git(url, path)



# -*- coding:utf-8 -*-
import pandas


class Code(object):
    """
    Code 类是一个接口，用于定义 Code 类的基本属性和方法，建议继承 Code类的类名设为 MyCode
    """

    def __init__(self, data: DataFrame):
        """
        初始化函数
        :param data:数据集，将数据集转化为 pandas.DataFrame
        """
        self.data = data

    def get_guide(self):
        """
        该函数为说备注函数，用于返回该数据集合的使用注意事项
        """
        pass

    def get_data(self):
        """
        返回数据样本
        """
        return self.data

    def preprocessing(self):
        """
        数据预处理函数,用于对数据集进行格式、缺失值、异常值等处理
        :return: 处理后的数据集,要求格式为 pandas.DataFrame，
        """
        pass
